# Copyright 2011 OpenStack LLC.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
A filter middleware that just outputs to logs, for instructive/sample
purposes only.
"""

from barbican.api import middleware
from barbican.common import utils

LOG = utils.getLogger(__name__)


class SimpleFilter(middleware.Middleware):

    def __init__(self, app):
        super(SimpleFilter, self).__init__(app)

    def process_request(self, req):
        """Just announce we have been called."""
        LOG.debug("Calling SimpleFilter")
        return None
